class Agent:
    def __init__(self, properties={}):
        """
        a class representing a computational unit with properties that can interact with other agents and with a space

        Attributes
        ----------
        properties: dictionary, default= {}
            the properties of the agent object
        id: int
            a unique id given to each agent (accessed by the Model class when creating the Agent)
        location_index: int, default= None
            the index to which the agent is assigned (accessed by the Model class when creating or moving the Agent)
        """
        self.my_class = None
        self.props = properties
        self.id = 0
        self.location_index = None
        self.location_xy = None

    def __str__(self):
        """
        Print function
        """
        if self.my_class != None:
            return f"{self.my_class} {self.id}"
        else:
            return f"Agent {self.id}"
        
    def __repr__(self):
        """
        Represent function
        """
        if self.my_class != None:
            return f"{self.my_class} {self.id}"
        else:
            return f"Agent {self.id}"


from setuptools import setup, find_packages

VERSION = '0.0.29' 
DESCRIPTION = 'Agent Based Pandas tool (ABPandas)'
LONG_DESCRIPTION = 'An Agent Based Modelling (ABM) package that can generate grid spatial shape files or work with predefined shape files.\nThe package focuses on simplicity by assigning Agents to spatial Polygons instead of assigning x and y locations for each agents.\nThis makes it useful in situations where granual movement of agents in space is not necessary (e.g. residentail location models)'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="abpandas", 
        version=VERSION,
        author="Yahya Gamal",
        author_email="<abpandas.yg@outlook.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=['geopandas', 'pandas', 'fiona', 'pyshp', 'shapely'], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['python', 'Agent Based Model', 'Spatial', 'Pandas'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Science/Research",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)